
.. image:: https://readthedocs.org/projects/wow-sdm/badge/?version=latest
    :target: https://wow-sdm.readthedocs.io/en/latest/
    :alt: Documentation Status

.. image:: https://github.com/MacHu-GWU/wow_sdm-project/workflows/CI/badge.svg
    :target: https://github.com/MacHu-GWU/wow_sdm-project/actions?query=workflow:CI

.. image:: https://codecov.io/gh/MacHu-GWU/wow_sdm-project/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/MacHu-GWU/wow_sdm-project

.. image:: https://img.shields.io/pypi/v/wow-sdm.svg
    :target: https://pypi.python.org/pypi/wow-sdm

.. image:: https://img.shields.io/pypi/l/wow-sdm.svg
    :target: https://pypi.python.org/pypi/wow-sdm

.. image:: https://img.shields.io/pypi/pyversions/wow-sdm.svg
    :target: https://pypi.python.org/pypi/wow-sdm

.. image:: https://img.shields.io/badge/Release_History!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/wow_sdm-project/blob/main/release-history.rst

.. image:: https://img.shields.io/badge/STAR_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/wow_sdm-project

------

.. image:: https://img.shields.io/badge/Link-Document-blue.svg
    :target: https://wow-sdm.readthedocs.io/en/latest/

.. image:: https://img.shields.io/badge/Link-API-blue.svg
    :target: https://wow-sdm.readthedocs.io/en/latest/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
    :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
    :target: https://github.com/MacHu-GWU/wow_sdm-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
    :target: https://github.com/MacHu-GWU/wow_sdm-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
    :target: https://github.com/MacHu-GWU/wow_sdm-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
    :target: https://pypi.org/pypi/wow-sdm#files


Welcome to ``wow_sdm`` Documentation
==============================================================================
.. image:: https://wow-sdm.readthedocs.io/en/latest/_static/wow_sdm-logo.png
    :target: https://wow-sdm.readthedocs.io/en/latest/

Manager your World of Warcraft macros configuration at scale.

这是一个强大的魔兽世界的宏命令管理工具.


.. _install:

Install
------------------------------------------------------------------------------

``wow_sdm`` is released on PyPI, so all you need is to:

.. code-block:: console

    $ pip install wow-sdm

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade wow-sdm
